# Useless Utilities!
## A collection of different bases such as ternary, quaternary, quinary and senary.

I do Plan to add more bases in the future.

## Usage:

use the corresponding function to convert to the base you want.
Such as:

ter(N) for ternary

quat(N) for quaternary

quin(N) for quinary

sen(N) for senary

## Expected releases:
### Septenary
A base-7 number system. Sep(N)
### Octonary
A base-8 number system. Oct(N)
### Nonary
A base-9 number system. Non(N)
### Duodecimal
A base-12 number system. Duodec(N)



# Changelog:

## V1.0.0:
- Initial release
- Included ternary, quaternary, quinary and senary
- Deleted due to inconsistancies

## V1.0.1:
- Fixed a bug with the senary function
- Added a changelog
- Fixed the inconsistancies in V1.0.0
- Fixed email address

## V1.0.2:
- Renamed some variables to better fit the base